netapp_ontap.resources.cluster_nis_service API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.resources.cluster_nis_service`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Overview

NIS servers are used to authenticate user and client computers. NIS domain name and NIS server information is required to configure NIS. This API retrieves and manages NIS server configurations.

## Examples

### Retrieving cluster NIS information

The cluster NIS GET request retrieves the NIS configuration of the cluster.
The following example shows how a GET request is used to retrieve the cluster NIS configuration:

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import ClusterNisService

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = ClusterNisService()
        resource.get()
        print(resource)

Try it out

    ClusterNisService(
        {
            "servers": ["10.10.10.10", "example.com"],
            "bound_servers": ["10.10.10.10"],
            "domain": "domainA.example.com",
        }
    )

### Creating the cluster NIS configuration

The cluster NIS POST request creates a NIS configuration for the cluster.
The following example shows how a POST request is used to create a cluster NIS configuration:

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import ClusterNisService

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = ClusterNisService()
        resource.domain = "domainA.example.com"
        resource.servers = ["10.10.10.10", "example.com"]
        resource.post(hydrate=True)
        print(resource)

### Updating the cluster NIS configuration

The cluster NIS PATCH request updates the NIS configuration of the cluster.
The following example shows how to update the domain:

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import ClusterNisService

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = ClusterNisService()
        resource.domain = "domainC.example.com"
        resource.servers = ["13.13.13.13"]
        resource.patch()

The following example shows how to update the server:

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import ClusterNisService

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = ClusterNisService()
        resource.servers = ["14.14.14.14"]
        resource.patch()

## Deleting the cluster NIS configuration

The cluster NIS DELETE request deletes the NIS configuration of the cluster.
The following example shows how a DELETE request is used to delete the cluster NIS configuration:

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import ClusterNisService

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = ClusterNisService()
        resource.delete()

## Classes

`class ClusterNisService (*args, **kwargs)`

  Allows interaction with ClusterNisService objects on the host

  Initialize the instance of the resource.

  Any keyword arguments are set on the instance as properties. For example, if the class was named 'MyResource', then this statement would be true:

      MyResource(name='foo').name == 'foo'

  ## Args

  `*args`
    Each positional argument represents a parent key as used in the URL of the object. That is, each value will be used to fill in a segment of the URL which refers to some parent object. The order of these arguments must match the order they are specified in the URL, from left to right.
  `**kwargs`
    each entry will have its key set as an attribute name on the instance and its value will be the value of that attribute.

  ### Ancestors

  - Resource

  ### Methods

  `def delete (self, body: Union[Resource, dict] = None, poll: bool = True, poll_interval: Optional[int] = None, poll_timeout: Optional[int] = None, **kwargs) -> NetAppResponse`

    Deletes the NIS configuration of the cluster. NIS can be removed as a source from ns-switch if NIS is not used for lookups.

    ### Learn more

    - `DOC /security/authentication/cluster/nis`

    Send a deletion request to the host for this object.

    ## Args

    `body`
      The body of the delete request. This could be a Resource instance or a dictionary object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def get (self, **kwargs) -> NetAppResponse`

    Retrieves the NIS configuration of the cluster. Both NIS domain and servers are displayed by default. The `bound_servers` property indicates the successfully bound NIS servers.

    ### Learn more

    - `DOC /security/authentication/cluster/nis`

    Fetch the details of the object from the host.

    Requires the keys to be set (if any). After returning, new or changed properties from the host will be set on the instance.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400 or if not all of the keys required are present and config.STRICT_GET has been set to True.

  `def patch (self, hydrate: bool = False, poll: bool = True, poll_interval: Optional[int] = None, poll_timeout: Optional[int] = None, **kwargs) -> NetAppResponse`

    Both NIS domain and servers can be updated. Domains and servers cannot be empty. Both FQDNs and IP addresses are supported for the 'servers' field. If the domain is updated, NIS servers must also be specified. IPv6 must be enabled if IPv6 family addresses are specified for the `servers` property.

    ### Learn more

    - `DOC /security/authentication/cluster/nis`

    Send the difference in the object's state to the host as a modification request.

    Calculates the difference in the object's state since the last time we interacted with the host and sends this in the request body.

    ## Args

    `hydrate`
      If set to True, after the response is received from the call, a a GET call will be made to refresh all fields of the object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will normally be sent as query parameters to the host. If any of these pairs are parameters that are sent as formdata then only parameters of that type will be accepted and all others will be discarded.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def post (self, hydrate: bool = False, poll: bool = True, poll_interval: Optional[int] = None, poll_timeout: Optional[int] = None, **kwargs) -> NetAppResponse`

    The cluster can have one NIS server configuration. Specify the NIS domain and NIS servers as input. The servers field cannot be empty. Both FQDNs and IP addresses are supported for the `server` property. IPv6 must be enabled if IPv6 family addresses are specified in the `server` property. A maximum of ten NIS servers are supported.

    ### Required properties

    - `domain` - NIS domain to which this configuration belongs.
    - `servers` - List of hostnames or IP addresses of NIS servers used by the NIS domain configuration.

    ### Learn more

    - `DOC /security/authentication/cluster/nis`

    Send this object to the host as a creation request.

    ## Args

    `hydrate`
      If set to True, after the response is received from the call, a a GET call will be made to refresh all fields of the object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will normally be sent as query parameters to the host. If any of these pairs are parameters that are sent as formdata then only parameters of that type will be accepted and all others will be discarded.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  ### Inherited members

  - `Resource`:
    - `from_dict`
    - `get_collection_url`
    - `get_connection`
    - `instance_location`
    - `path_keys`
    - `poll`
    - `set_connection`
    - `to_dict`
    - `validate_schema`
`class ClusterNisServiceSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the ClusterNisService object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `binding_details: List[BindingDetails] GET`

    An array of objects where each object represents the NIS server and it's status for a given NIS domain. It is an advanced field.

  `bound_servers: List[str] GET`

    The bound_servers field of the cluster_nis_service.

  `domain: str GET POST PATCH`

    The NIS domain to which this configuration belongs.

  `links: SelfLink GET`

    The links field of the cluster_nis_service.

  `servers: List[str] GET POST PATCH`

    A list of hostnames or IP addresses of NIS servers used by the NIS domain configuration.